@@ -6,27 +6,27 @@ log.debug(log.debug, f'variant: {EnvironmentHelper.get("URL_VARIANT")}')
 
 from python_helper import TestHelper
 # TestHelper.run(__file__)
-# TestHelper.run(
-#     __file__,
-#     runOnly = [
-#         'SerializerTest.getClassRole',
-#         'SerializerTest.importResource',
-#         'SerializerTest.convertFromObjectToObject',
-#         'SerializerTest.convertFromObjectToObject_whenTargetClassIsList',
-#         'SerializerTest.isModelTest',
-#         'SerializerTest.isJsonifyable',
-#         'SerializerTest.jsonifyIt',
-#         'SerializerTest.fromDtoToModel',
-#         'SerializerTest.fromModelToDto',
-#         'SerializerTest.convertFromJsonToObject_whenThereAreEnums',
-#         'SerializerTest.convertFromObjectToObject_weirdIdList',
-#         'SerializerTest.convertFromJsonToObject_nativeClassAtributeList',
-#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenNotFound',
-#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundButInvalid',
-#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValid',
-#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValidKeepingDataType'
-#     ]
-# )
+TestHelper.run(
+    __file__,
+    runOnly = [
+        'SerializerTest.getClassRole',
+        'SerializerTest.importResource',
+        'SerializerTest.convertFromObjectToObject',
+        'SerializerTest.convertFromObjectToObject_whenTargetClassIsList',
+        'SerializerTest.isModelTest',
+        'SerializerTest.isJsonifyable',
+        'SerializerTest.jsonifyIt',
+        'SerializerTest.fromDtoToModel',
+        'SerializerTest.fromModelToDto',
+        'SerializerTest.convertFromJsonToObject_whenThereAreEnums',
+        'SerializerTest.convertFromObjectToObject_weirdIdList',
+        'SerializerTest.convertFromJsonToObject_nativeClassAtributeList',
+        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenNotFound',
+        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundButInvalid',
+        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValid',
+        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValidKeepingDataType'
+    ]
+)
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
